You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vo...@apache.org on 2015/02/02 11:29:02 UTC

[26/50] [abbrv] incubator-ignite git commit: # sprint-1 moved existing IgniteFuture to internal package

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/processors/service/GridServiceProcessor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/service/GridServiceProcessor.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/service/GridServiceProcessor.java
index 4d2ece7..8db40b9 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/service/GridServiceProcessor.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/service/GridServiceProcessor.java
@@ -147,13 +147,13 @@ public class GridServiceProcessor extends GridProcessorAdapter {
         ManagedServiceConfiguration[] cfgs = ctx.config().getServiceConfiguration();
 
         if (cfgs != null) {
-            Collection<IgniteFuture<?>> futs = new ArrayList<>();
+            Collection<IgniteInternalFuture<?>> futs = new ArrayList<>();
 
             for (ManagedServiceConfiguration c : ctx.config().getServiceConfiguration())
                 futs.add(deploy(c));
 
             // Await for services to deploy.
-            for (IgniteFuture<?> f : futs)
+            for (IgniteInternalFuture<?> f : futs)
                 f.get();
         }
 
@@ -262,7 +262,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param svc Service.
      * @return Future.
      */
-    public IgniteFuture<?> deployNodeSingleton(ClusterGroup prj, String name, ManagedService svc) {
+    public IgniteInternalFuture<?> deployNodeSingleton(ClusterGroup prj, String name, ManagedService svc) {
         return deployMultiple(prj, name, svc, 0, 1);
     }
 
@@ -271,7 +271,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param svc Service.
      * @return Future.
      */
-    public IgniteFuture<?> deployClusterSingleton(ClusterGroup prj, String name, ManagedService svc) {
+    public IgniteInternalFuture<?> deployClusterSingleton(ClusterGroup prj, String name, ManagedService svc) {
         return deployMultiple(prj, name, svc, 1, 1);
     }
 
@@ -282,7 +282,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param maxPerNodeCnt Max per-node count.
      * @return Future.
      */
-    public IgniteFuture<?> deployMultiple(ClusterGroup prj, String name, ManagedService svc, int totalCnt,
+    public IgniteInternalFuture<?> deployMultiple(ClusterGroup prj, String name, ManagedService svc, int totalCnt,
         int maxPerNodeCnt) {
         ManagedServiceConfiguration cfg = new ManagedServiceConfiguration();
 
@@ -302,7 +302,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param  affKey Affinity key.
      * @return Future.
      */
-    public IgniteFuture<?> deployKeyAffinitySingleton(String name, ManagedService svc, String cacheName, Object affKey) {
+    public IgniteInternalFuture<?> deployKeyAffinitySingleton(String name, ManagedService svc, String cacheName, Object affKey) {
         A.notNull(affKey, "affKey");
 
         ManagedServiceConfiguration cfg = new ManagedServiceConfiguration();
@@ -321,7 +321,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param cfg Service configuration.
      * @return Future for deployment.
      */
-    public IgniteFuture<?> deploy(ManagedServiceConfiguration cfg) {
+    public IgniteInternalFuture<?> deploy(ManagedServiceConfiguration cfg) {
         A.notNull(cfg, "cfg");
 
         validate(cfg);
@@ -412,7 +412,7 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @param name Service name.
      * @return Future.
      */
-    public IgniteFuture<?> cancel(String name) {
+    public IgniteInternalFuture<?> cancel(String name) {
         while (true) {
             try {
                 GridFutureAdapter<?> fut = new GridFutureAdapter<>(ctx);
@@ -450,8 +450,8 @@ public class GridServiceProcessor extends GridProcessorAdapter {
      * @return Future.
      */
     @SuppressWarnings("unchecked")
-    public IgniteFuture<?> cancelAll() {
-        Collection<IgniteFuture<?>> futs = new ArrayList<>();
+    public IgniteInternalFuture<?> cancelAll() {
+        Collection<IgniteInternalFuture<?>> futs = new ArrayList<>();
 
         for (CacheEntry<Object, Object> e : cache.entrySetx()) {
             if (!(e.getKey() instanceof GridServiceDeploymentKey))

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/processors/streamer/IgniteStreamerImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/streamer/IgniteStreamerImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/streamer/IgniteStreamerImpl.java
index 3542615..760cf12 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/streamer/IgniteStreamerImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/streamer/IgniteStreamerImpl.java
@@ -751,8 +751,8 @@ public class IgniteStreamerImpl implements IgniteStreamerEx, Externalizable {
 
             execSvc.submit(worker);
 
-            batchFut.listenAsync(new CI1<IgniteFuture<Object>>() {
-                @Override public void apply(IgniteFuture<Object> t) {
+            batchFut.listenAsync(new CI1<IgniteInternalFuture<Object>>() {
+                @Override public void apply(IgniteInternalFuture<Object> t) {
                     BatchExecutionFuture fut = (BatchExecutionFuture)t;
 
                     if (log.isDebugEnabled())

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java b/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
index 82ae077..f384437 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/GridUtils.java
@@ -7289,10 +7289,10 @@ public abstract class GridUtils {
      * @param f Future to listen to.
      * @param log Logger.
      */
-    public static void asyncLogError(IgniteFuture<?> f, final IgniteLogger log) {
+    public static void asyncLogError(IgniteInternalFuture<?> f, final IgniteLogger log) {
         if (f != null)
-            f.listenAsync(new CI1<IgniteFuture<?>>() {
-                @Override public void apply(IgniteFuture<?> f) {
+            f.listenAsync(new CI1<IgniteInternalFuture<?>>() {
+                @Override public void apply(IgniteInternalFuture<?> f) {
                     try {
                         f.get();
                     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundFuture.java
index 47bc380..db16ae8 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundFuture.java
@@ -40,10 +40,10 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
     private static final long serialVersionUID = 0L;
 
     /** Futures. */
-    private final ConcurrentLinkedDeque8<IgniteFuture<T>> futs = new ConcurrentLinkedDeque8<>();
+    private final ConcurrentLinkedDeque8<IgniteInternalFuture<T>> futs = new ConcurrentLinkedDeque8<>();
 
     /** Pending futures. */
-    private final Collection<IgniteFuture<T>> pending = new ConcurrentLinkedDeque8<>();
+    private final Collection<IgniteInternalFuture<T>> pending = new ConcurrentLinkedDeque8<>();
 
     /** Listener call count. */
     private final AtomicInteger lsnrCalls = new AtomicInteger();
@@ -97,7 +97,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      * @param futs Futures to add.
      */
     public GridCompoundFuture(GridKernalContext ctx, @Nullable IgniteReducer<T, R> rdc,
-        @Nullable Iterable<IgniteFuture<T>> futs) {
+        @Nullable Iterable<IgniteInternalFuture<T>> futs) {
         super(ctx);
 
         this.rdc = rdc;
@@ -108,7 +108,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
     /** {@inheritDoc} */
     @Override public boolean cancel() throws IgniteCheckedException {
         if (onCancelled()) {
-            for (IgniteFuture<T> fut : futs)
+            for (IgniteInternalFuture<T> fut : futs)
                 fut.cancel();
 
             return true;
@@ -122,7 +122,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      *
      * @return Collection of futures.
      */
-    public Collection<IgniteFuture<T>> futures() {
+    public Collection<IgniteInternalFuture<T>> futures() {
         return futs;
     }
 
@@ -131,7 +131,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      *
      * @return Pending futures.
      */
-    public Collection<IgniteFuture<T>> pending() {
+    public Collection<IgniteInternalFuture<T>> pending() {
         return pending;
     }
 
@@ -166,7 +166,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      *
      * @param fut Future to add.
      */
-    public void add(IgniteFuture<T> fut) {
+    public void add(IgniteInternalFuture<T> fut) {
         assert fut != null;
 
         pending.add(fut);
@@ -188,7 +188,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      *
      * @param futs Futures to add.
      */
-    public void addAll(@Nullable IgniteFuture<T>... futs) {
+    public void addAll(@Nullable IgniteInternalFuture<T>... futs) {
         addAll(F.asList(futs));
     }
 
@@ -197,9 +197,9 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
      *
      * @param futs Futures to add.
      */
-    public void addAll(@Nullable Iterable<IgniteFuture<T>> futs) {
+    public void addAll(@Nullable Iterable<IgniteInternalFuture<T>> futs) {
         if (futs != null)
-            for (IgniteFuture<T> fut : futs)
+            for (IgniteInternalFuture<T> fut : futs)
                 add(fut);
     }
 
@@ -291,8 +291,8 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
             "cancelled", isCancelled(),
             "err", error(),
             "futs",
-                F.viewReadOnly(futs, new C1<IgniteFuture<T>, String>() {
-                    @Override public String apply(IgniteFuture<T> f) {
+                F.viewReadOnly(futs, new C1<IgniteInternalFuture<T>, String>() {
+                    @Override public String apply(IgniteInternalFuture<T> f) {
                         return Boolean.toString(f.isDone());
                     }
                 })
@@ -302,12 +302,12 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
     /**
      * Listener for futures.
      */
-    private class Listener implements IgniteInClosure<IgniteFuture<T>> {
+    private class Listener implements IgniteInClosure<IgniteInternalFuture<T>> {
         /** */
         private static final long serialVersionUID = 0L;
 
         /** {@inheritDoc} */
-        @Override public void apply(IgniteFuture<T> fut) {
+        @Override public void apply(IgniteInternalFuture<T> fut) {
             pending.remove(fut);
 
             try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundIdentityFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundIdentityFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundIdentityFuture.java
index cf5323c..85b898c 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundIdentityFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridCompoundIdentityFuture.java
@@ -57,7 +57,7 @@ public class GridCompoundIdentityFuture<T> extends GridCompoundFuture<T, T> {
      * @param futs Futures to add.
      */
     public GridCompoundIdentityFuture(GridKernalContext ctx, @Nullable IgniteReducer<T, T> rdc,
-        @Nullable Iterable<IgniteFuture<T>> futs) {
+        @Nullable Iterable<IgniteInternalFuture<T>> futs) {
         super(ctx, rdc, futs);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridEmbeddedFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridEmbeddedFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridEmbeddedFuture.java
index 516b0fc..e3df9f5 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridEmbeddedFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridEmbeddedFuture.java
@@ -35,7 +35,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
     private static final long serialVersionUID = 0L;
 
     /** Embedded future to wait for. */
-    private IgniteFuture<B> embedded;
+    private IgniteInternalFuture<B> embedded;
 
     /**
      * Empty constructor required by {@link Externalizable}.
@@ -49,7 +49,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
      * @param embedded Embedded future.
      * @param c Closure to execute upon completion of embedded future.
      */
-    public GridEmbeddedFuture(GridKernalContext ctx, IgniteFuture<B> embedded, final IgniteBiClosure<B, Exception, A> c) {
+    public GridEmbeddedFuture(GridKernalContext ctx, IgniteInternalFuture<B> embedded, final IgniteBiClosure<B, Exception, A> c) {
         super(ctx);
 
         assert embedded != null;
@@ -59,7 +59,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
 
         embedded.listenAsync(new AL1() {
             @SuppressWarnings({"ErrorNotRethrown", "CatchGenericClass"})
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(IgniteInternalFuture<B> embedded) {
                 try {
                     onDone(c.apply(embedded.get(), null));
                 }
@@ -83,7 +83,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
      * @param c Closure which runs upon completion of embedded closure and which returns another future.
      * @param ctx Context.
      */
-    public GridEmbeddedFuture(boolean syncNotify, IgniteFuture<B> embedded, IgniteBiClosure<B, Exception, IgniteFuture<A>> c,
+    public GridEmbeddedFuture(boolean syncNotify, IgniteInternalFuture<B> embedded, IgniteBiClosure<B, Exception, IgniteInternalFuture<A>> c,
         GridKernalContext ctx) {
         this(embedded, c, ctx);
 
@@ -97,7 +97,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
      * @param embedded Closure.
      * @param c Closure which runs upon completion of embedded closure and which returns another future.
      */
-    public GridEmbeddedFuture(IgniteFuture<B> embedded, final IgniteBiClosure<B, Exception, IgniteFuture<A>> c,
+    public GridEmbeddedFuture(IgniteInternalFuture<B> embedded, final IgniteBiClosure<B, Exception, IgniteInternalFuture<A>> c,
         GridKernalContext ctx) {
         super(ctx);
 
@@ -107,9 +107,9 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
         this.embedded = embedded;
 
         embedded.listenAsync(new AL1() {
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(IgniteInternalFuture<B> embedded) {
                 try {
-                    IgniteFuture<A> next = c.apply(embedded.get(), null);
+                    IgniteInternalFuture<A> next = c.apply(embedded.get(), null);
 
                     if (next == null) {
                         onDone();
@@ -118,7 +118,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
                     }
 
                     next.listenAsync(new AL2() {
-                        @Override public void applyx(IgniteFuture<A> next) {
+                        @Override public void applyx(IgniteInternalFuture<A> next) {
                             try {
                                 onDone(next.get());
                             }
@@ -163,8 +163,8 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
      * @param c1 Closure which runs upon completion of embedded future and which returns another future.
      * @param c2 Closure will runs upon completion of future returned by {@code c1} closure.
      */
-    public GridEmbeddedFuture(GridKernalContext ctx, IgniteFuture<B> embedded, final IgniteBiClosure<B, Exception,
-        IgniteFuture<A>> c1, final IgniteBiClosure<A, Exception, A> c2) {
+    public GridEmbeddedFuture(GridKernalContext ctx, IgniteInternalFuture<B> embedded, final IgniteBiClosure<B, Exception,
+        IgniteInternalFuture<A>> c1, final IgniteBiClosure<A, Exception, A> c2) {
         super(ctx);
 
         assert embedded != null;
@@ -174,9 +174,9 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
         this.embedded = embedded;
 
         embedded.listenAsync(new AL1() {
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(IgniteInternalFuture<B> embedded) {
                 try {
-                    IgniteFuture<A> next = c1.apply(embedded.get(), null);
+                    IgniteInternalFuture<A> next = c1.apply(embedded.get(), null);
 
                     if (next == null) {
                         onDone();
@@ -185,7 +185,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
                     }
 
                     next.listenAsync(new AL2() {
-                        @Override public void applyx(IgniteFuture<A> next) {
+                        @Override public void applyx(IgniteInternalFuture<A> next) {
                             try {
                                 onDone(c2.apply(next.get(), null));
                             }
@@ -258,12 +258,12 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
     /**
      * Make sure that listener does not throw exceptions.
      */
-    private abstract class AsyncListener1 implements IgniteInClosure<IgniteFuture<B>> {
+    private abstract class AsyncListener1 implements IgniteInClosure<IgniteInternalFuture<B>> {
         /** */
         private static final long serialVersionUID = 0L;
 
         /** {@inheritDoc} */
-        @Override public final void apply(IgniteFuture<B> f) {
+        @Override public final void apply(IgniteInternalFuture<B> f) {
             try {
                 applyx(f);
             }
@@ -284,18 +284,18 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
          * @param f Future.
          * @throws Exception In case of error.
          */
-        protected abstract void applyx(IgniteFuture<B> f) throws Exception;
+        protected abstract void applyx(IgniteInternalFuture<B> f) throws Exception;
     }
 
     /**
      * Make sure that listener does not throw exceptions.
      */
-    private abstract class AsyncListener2 implements IgniteInClosure<IgniteFuture<A>> {
+    private abstract class AsyncListener2 implements IgniteInClosure<IgniteInternalFuture<A>> {
         /** */
         private static final long serialVersionUID = 0L;
 
         /** {@inheritDoc} */
-        @Override public final void apply(IgniteFuture<A> f) {
+        @Override public final void apply(IgniteInternalFuture<A> f) {
             try {
                 applyx(f);
             }
@@ -316,6 +316,6 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
          * @param f Future.
          * @throws Exception In case of error.
          */
-        protected abstract void applyx(IgniteFuture<A> f) throws Exception;
+        protected abstract void applyx(IgniteInternalFuture<A> f) throws Exception;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFuture.java
index 8ff11af..d4039c0 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFuture.java
@@ -31,7 +31,7 @@ import static org.apache.ignite.IgniteSystemProperties.*;
 /**
  * Future that is completed at creation time.
  */
-public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
+public class GridFinishedFuture<T> implements IgniteInternalFuture<T>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -166,7 +166,7 @@ public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public void listenAsync(final IgniteInClosure<? super IgniteFuture<T>> lsnr) {
+    @Override public void listenAsync(final IgniteInClosure<? super IgniteInternalFuture<T>> lsnr) {
         if (ctx == null)
             throw new IllegalStateException("Cannot attach listener to deserialized future (context is null): " + this);
 
@@ -183,12 +183,12 @@ public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteFuture<T>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteInternalFuture<T>>... lsnr) {
         // No-op.
     }
 
     /** {@inheritDoc} */
-    @Override public <R> IgniteFuture<R> chain(final IgniteClosure<? super IgniteFuture<T>, R> doneCb) {
+    @Override public <R> IgniteInternalFuture<R> chain(final IgniteClosure<? super IgniteInternalFuture<T>, R> doneCb) {
         GridFutureAdapter<R> fut = new GridFutureAdapter<R>(ctx, syncNotify) {
             @Override public String toString() {
                 return "ChainFuture[orig=" + GridFinishedFuture.this + ", doneCb=" + doneCb + ']';

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFutureEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFutureEx.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFutureEx.java
index 0db9f20..6daf3b2 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFutureEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFinishedFutureEx.java
@@ -18,6 +18,7 @@
 package org.apache.ignite.internal.util.future;
 
 import org.apache.ignite.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.lang.*;
 import org.apache.ignite.internal.util.typedef.internal.*;
@@ -31,7 +32,7 @@ import java.util.concurrent.*;
  * {@link GridFinishedFuture} as it does not take context as a parameter and
  * performs notifications in the same thread.
  */
-public class GridFinishedFutureEx<T> implements IgniteFuture<T>, Externalizable {
+public class GridFinishedFutureEx<T> implements IgniteInternalFuture<T>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -143,7 +144,7 @@ public class GridFinishedFutureEx<T> implements IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public <R> IgniteFuture<R> chain(IgniteClosure<? super IgniteFuture<T>, R> doneCb) {
+    @Override public <R> IgniteInternalFuture<R> chain(IgniteClosure<? super IgniteInternalFuture<T>, R> doneCb) {
         try {
             return new GridFinishedFutureEx<>(doneCb.apply(this));
         }
@@ -159,13 +160,13 @@ public class GridFinishedFutureEx<T> implements IgniteFuture<T>, Externalizable
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked"})
-    @Override public void listenAsync(IgniteInClosure<? super IgniteFuture<T>> lsnr) {
+    @Override public void listenAsync(IgniteInClosure<? super IgniteInternalFuture<T>> lsnr) {
         if (lsnr != null)
             lsnr.apply(this);
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteFuture<T>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteInternalFuture<T>>... lsnr) {
         // No-op.
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapter.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapter.java
index eb7a0bf..9a8a439 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapter.java
@@ -35,7 +35,7 @@ import static org.apache.ignite.IgniteSystemProperties.*;
 /**
  * Future adapter.
  */
-public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements IgniteFuture<R>, Externalizable {
+public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements IgniteInternalFuture<R>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -77,7 +77,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     private boolean valid = true;
 
     /** Asynchronous listeners. */
-    private Collection<IgniteInClosure<? super IgniteFuture<R>>> lsnrs;
+    private Collection<IgniteInClosure<? super IgniteInternalFuture<R>>> lsnrs;
 
     /** Context. */
     protected GridKernalContext ctx;
@@ -259,7 +259,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public void listenAsync(@Nullable final IgniteInClosure<? super IgniteFuture<R>> lsnr) {
+    @Override public void listenAsync(@Nullable final IgniteInClosure<? super IgniteInternalFuture<R>> lsnr) {
         if (lsnr != null) {
             checkValid();
 
@@ -298,7 +298,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteFuture<R>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteInternalFuture<R>>... lsnr) {
         synchronized (mux) {
             if (lsnrs == null)
                 return;
@@ -307,10 +307,10 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
                 lsnrs.clear();
             else {
                 // Iterate through the whole list, removing all occurrences, if any.
-                for (Iterator<IgniteInClosure<? super IgniteFuture<R>>> it = lsnrs.iterator(); it.hasNext();) {
-                    IgniteInClosure<? super IgniteFuture<R>> l1 = it.next();
+                for (Iterator<IgniteInClosure<? super IgniteInternalFuture<R>>> it = lsnrs.iterator(); it.hasNext();) {
+                    IgniteInClosure<? super IgniteInternalFuture<R>> l1 = it.next();
 
-                    for (IgniteInClosure<? super IgniteFuture<R>> l2 : lsnr)
+                    for (IgniteInClosure<? super IgniteInternalFuture<R>> l2 : lsnr)
                         // Must be l1.equals(l2), not l2.equals(l1), because of the way listeners are added.
                         if (l1.equals(l2))
                             it.remove();
@@ -320,7 +320,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public <T> IgniteFuture<T> chain(final IgniteClosure<? super IgniteFuture<R>, T> doneCb) {
+    @Override public <T> IgniteInternalFuture<T> chain(final IgniteClosure<? super IgniteInternalFuture<R>, T> doneCb) {
         return new ChainFuture<>(ctx, syncNotify, this, doneCb);
     }
 
@@ -328,7 +328,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
      * Notifies all registered listeners.
      */
     private void notifyListeners() {
-        final Collection<IgniteInClosure<? super IgniteFuture<R>>> lsnrs0;
+        final Collection<IgniteInClosure<? super IgniteInternalFuture<R>>> lsnrs0;
 
         synchronized (mux) {
             lsnrs0 = lsnrs;
@@ -342,7 +342,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
         assert !lsnrs0.isEmpty();
 
         if (concurNotify) {
-            for (final IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs0)
+            for (final IgniteInClosure<? super IgniteInternalFuture<R>> lsnr : lsnrs0)
                 ctx.closure().runLocalSafe(new GPR() {
                     @Override public void run() {
                         notifyListener(lsnr);
@@ -356,13 +356,13 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
                     @Override public void run() {
                         // Since concurrent notifications are off, we notify
                         // all listeners in one thread.
-                        for (IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs0)
+                        for (IgniteInClosure<? super IgniteInternalFuture<R>> lsnr : lsnrs0)
                             notifyListener(lsnr);
                     }
                 }, true);
             }
             else
-                for (IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs0)
+                for (IgniteInClosure<? super IgniteInternalFuture<R>> lsnr : lsnrs0)
                     notifyListener(lsnr);
         }
     }
@@ -372,7 +372,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
      *
      * @param lsnr Listener.
      */
-    private void notifyListener(IgniteInClosure<? super IgniteFuture<R>> lsnr) {
+    private void notifyListener(IgniteInClosure<? super IgniteInternalFuture<R>> lsnr) {
         assert lsnr != null;
 
         try {
@@ -593,7 +593,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
         private GridFutureAdapter<R> fut;
 
         /** */
-        private IgniteClosure<? super IgniteFuture<R>, T> doneCb;
+        private IgniteClosure<? super IgniteInternalFuture<R>, T> doneCb;
 
         /**
          *
@@ -609,7 +609,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
          * @param doneCb Closure.
          */
         ChainFuture(GridKernalContext ctx, boolean syncNotify,
-            GridFutureAdapter<R> fut, IgniteClosure<? super IgniteFuture<R>, T> doneCb) {
+            GridFutureAdapter<R> fut, IgniteClosure<? super IgniteInternalFuture<R>, T> doneCb) {
             super(ctx, syncNotify);
 
             this.fut = fut;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapterEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapterEx.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapterEx.java
index 177561a..6d60b92 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapterEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureAdapterEx.java
@@ -18,6 +18,7 @@
 package org.apache.ignite.internal.util.future;
 
 import org.apache.ignite.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.lang.*;
 import org.apache.ignite.internal.util.tostring.*;
@@ -34,7 +35,7 @@ import java.util.concurrent.locks.*;
 /**
  * Future adapter without kernal context.
  */
-public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implements IgniteFuture<R>, Externalizable {
+public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implements IgniteInternalFuture<R>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -64,7 +65,7 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
     private boolean valid = true;
 
     /** Asynchronous listener. */
-    private final ConcurrentLinkedDeque8<IgniteInClosure<? super IgniteFuture<R>>>
+    private final ConcurrentLinkedDeque8<IgniteInClosure<? super IgniteInternalFuture<R>>>
         lsnrs = new ConcurrentLinkedDeque8<>();
 
     /**
@@ -209,21 +210,21 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked", "TooBroadScope"})
-    @Override public void listenAsync(@Nullable final IgniteInClosure<? super IgniteFuture<R>> lsnr) {
+    @Override public void listenAsync(@Nullable final IgniteInClosure<? super IgniteInternalFuture<R>> lsnr) {
         if (lsnr != null) {
             checkValid();
 
             boolean done;
 
-            IgniteInClosure<? super IgniteFuture<R>> lsnr0 = lsnr;
+            IgniteInClosure<? super IgniteInternalFuture<R>> lsnr0 = lsnr;
 
             done = isDone();
 
             if (!done) {
-                lsnr0 = new IgniteInClosure<IgniteFuture<R>>() {
+                lsnr0 = new IgniteInClosure<IgniteInternalFuture<R>>() {
                     private final AtomicBoolean called = new AtomicBoolean();
 
-                    @Override public void apply(IgniteFuture<R> t) {
+                    @Override public void apply(IgniteInternalFuture<R> t) {
                         if (called.compareAndSet(false, true))
                             lsnr.apply(t);
                     }
@@ -248,15 +249,15 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteFuture<R>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteInternalFuture<R>>... lsnr) {
         if (lsnr == null || lsnr.length == 0)
             lsnrs.clear();
         else {
             // Iterate through the whole list, removing all occurrences, if any.
-            for (Iterator<IgniteInClosure<? super IgniteFuture<R>>> it = lsnrs.iterator(); it.hasNext(); ) {
-                IgniteInClosure<? super IgniteFuture<R>> l1 = it.next();
+            for (Iterator<IgniteInClosure<? super IgniteInternalFuture<R>>> it = lsnrs.iterator(); it.hasNext(); ) {
+                IgniteInClosure<? super IgniteInternalFuture<R>> l1 = it.next();
 
-                for (IgniteInClosure<? super IgniteFuture<R>> l2 : lsnr)
+                for (IgniteInClosure<? super IgniteInternalFuture<R>> l2 : lsnr)
                     // Must be l1.equals(l2), not l2.equals(l1), because of the way listeners are added.
                     if (l1.equals(l2))
                         it.remove();
@@ -265,15 +266,15 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public <T> IgniteFuture<T> chain(final IgniteClosure<? super IgniteFuture<R>, T> doneCb) {
+    @Override public <T> IgniteInternalFuture<T> chain(final IgniteClosure<? super IgniteInternalFuture<R>, T> doneCb) {
         final GridFutureAdapterEx<T> fut = new GridFutureAdapterEx<T>() {
             @Override public String toString() {
                 return "ChainFuture[orig=" + GridFutureAdapterEx.this + ", doneCb=" + doneCb + ']';
             }
         };
 
-        listenAsync(new IgniteInClosure<IgniteFuture<R>>() {
-            @Override public void apply(IgniteFuture<R> t) {
+        listenAsync(new IgniteInClosure<IgniteInternalFuture<R>>() {
+            @Override public void apply(IgniteInternalFuture<R> t) {
                 try {
                     fut.onDone(doneCb.apply(t));
                 }
@@ -309,7 +310,7 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
         if (lsnrs.isEmptyx())
             return;
 
-        for (IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs)
+        for (IgniteInClosure<? super IgniteInternalFuture<R>> lsnr : lsnrs)
             notifyListener(lsnr);
     }
 
@@ -318,7 +319,7 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
      *
      * @param lsnr Listener.
      */
-    private void notifyListener(IgniteInClosure<? super IgniteFuture<R>> lsnr) {
+    private void notifyListener(IgniteInClosure<? super IgniteInternalFuture<R>> lsnr) {
         assert lsnr != null;
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureChainListener.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureChainListener.java b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureChainListener.java
index 542f4a8..7caba83 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureChainListener.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/future/GridFutureChainListener.java
@@ -25,7 +25,7 @@ import org.apache.ignite.internal.util.lang.*;
 /**
  * Future listener to fill chained future with converted result of the source future.
  */
-public class GridFutureChainListener<T, R> implements IgniteInClosure<IgniteFuture<T>> {
+public class GridFutureChainListener<T, R> implements IgniteInClosure<IgniteInternalFuture<T>> {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -36,7 +36,7 @@ public class GridFutureChainListener<T, R> implements IgniteInClosure<IgniteFutu
     private final GridFutureAdapter<R> fut;
 
     /** Done callback. */
-    private final IgniteClosure<? super IgniteFuture<T>, R> doneCb;
+    private final IgniteClosure<? super IgniteInternalFuture<T>, R> doneCb;
 
     /**
      * Constructs chain listener.
@@ -46,14 +46,14 @@ public class GridFutureChainListener<T, R> implements IgniteInClosure<IgniteFutu
      * @param doneCb Done callback.
      */
     public GridFutureChainListener(GridKernalContext ctx, GridFutureAdapter<R> fut,
-        IgniteClosure<? super IgniteFuture<T>, R> doneCb) {
+        IgniteClosure<? super IgniteInternalFuture<T>, R> doneCb) {
         this.ctx = ctx;
         this.fut = fut;
         this.doneCb = doneCb;
     }
 
     /** {@inheritDoc} */
-    @Override public void apply(IgniteFuture<T> t) {
+    @Override public void apply(IgniteInternalFuture<T> t) {
         try {
             fut.onDone(doneCb.apply(t));
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/nio/GridNioFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/util/nio/GridNioFuture.java
index 9ba7a9b..bdd4383 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/nio/GridNioFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/nio/GridNioFuture.java
@@ -25,7 +25,7 @@ import java.io.*;
 import java.util.concurrent.*;
 
 /**
- * Reduced variant of {@link org.apache.ignite.lang.IgniteFuture} interface. Removed asynchronous
+ * Reduced variant of {@link org.apache.ignite.internal.IgniteInternalFuture} interface. Removed asynchronous
  * listen methods which require a valid grid kernal context.
  * @param <R> Type of the result for the future.
  */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java b/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
index 6cf45e9..9695249 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/typedef/X.java
@@ -18,8 +18,8 @@
 package org.apache.ignite.internal.util.typedef;
 
 import org.apache.ignite.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.util.*;
-import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -821,11 +821,11 @@ public final class X {
      * @param futs Futures to wait for.
      * @throws IgniteCheckedException If any of the futures threw exception.
      */
-    public static void waitAll(@Nullable Iterable<IgniteFuture<?>> futs) throws IgniteCheckedException {
+    public static void waitAll(@Nullable Iterable<IgniteInternalFuture<?>> futs) throws IgniteCheckedException {
         if (F.isEmpty(futs))
             return;
 
-        for (IgniteFuture fut : futs)
+        for (IgniteInternalFuture fut : futs)
             fut.get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/visor/cache/VisorCachePreloadTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/visor/cache/VisorCachePreloadTask.java b/modules/core/src/main/java/org/apache/ignite/internal/visor/cache/VisorCachePreloadTask.java
index 4d4b8ce..8b7c446 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/visor/cache/VisorCachePreloadTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/visor/cache/VisorCachePreloadTask.java
@@ -19,7 +19,7 @@ package org.apache.ignite.internal.visor.cache;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.lang.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.processors.task.*;
 import org.apache.ignite.internal.visor.*;
 import org.apache.ignite.internal.util.typedef.internal.*;
@@ -56,14 +56,14 @@ public class VisorCachePreloadTask extends VisorOneNodeTask<Set<String>, Void> {
 
         /** {@inheritDoc} */
         @Override protected Void run(Set<String> cacheNames) throws IgniteCheckedException {
-            Collection<IgniteFuture<?>> futs = new ArrayList<>();
+            Collection<IgniteInternalFuture<?>> futs = new ArrayList<>();
 
             for(GridCache c : g.cachesx()) {
                 if (cacheNames.contains(c.name()))
                     futs.add(c.forceRepartition());
             }
 
-            for (IgniteFuture f: futs)
+            for (IgniteInternalFuture f: futs)
                 f.get();
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupport.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupport.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupport.java
index 4540e8c..23226a1 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupport.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupport.java
@@ -17,6 +17,8 @@
 
 package org.apache.ignite.lang;
 
+import org.apache.ignite.internal.*;
+
 /**
  * TODO: Add interface description.
  */
@@ -38,5 +40,5 @@ public interface IgniteAsyncSupport {
      *
      * @return Future for previous asynchronous operation.
      */
-    public <R> IgniteFuture<R> future();
+    public <R> IgniteInternalFuture<R> future();
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
index 63cf9f5..e9ab2a1 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
@@ -18,6 +18,7 @@
 package org.apache.ignite.lang;
 
 import org.apache.ignite.*;
+import org.apache.ignite.internal.*;
 
 /**
  * Adapter for {@link IgniteAsyncSupport}.
@@ -27,7 +28,7 @@ public class IgniteAsyncSupportAdapter<T extends IgniteAsyncSupport> implements
     private static final Object mux = new Object();
 
     /** Future for previous asynchronous operation. */
-    protected ThreadLocal<IgniteFuture<?>> curFut;
+    protected ThreadLocal<IgniteInternalFuture<?>> curFut;
 
     /** */
     private volatile T asyncInstance;
@@ -81,18 +82,18 @@ public class IgniteAsyncSupportAdapter<T extends IgniteAsyncSupport> implements
     }
 
     /** {@inheritDoc} */
-    @Override public <R> IgniteFuture<R> future() {
+    @Override public <R> IgniteInternalFuture<R> future() {
         if (curFut == null)
             throw new IllegalStateException("Asynchronous mode is disabled.");
 
-        IgniteFuture<?> fut = curFut.get();
+        IgniteInternalFuture<?> fut = curFut.get();
 
         if (fut == null)
             throw new IllegalStateException("Asynchronous operation not started.");
 
         curFut.set(null);
 
-        return (IgniteFuture<R>)fut;
+        return (IgniteInternalFuture<R>)fut;
     }
 
     /**
@@ -101,7 +102,7 @@ public class IgniteAsyncSupportAdapter<T extends IgniteAsyncSupport> implements
      *         otherwise waits for future and returns result.
      * @throws IgniteCheckedException If asynchronous mode is disabled and future failed.
      */
-    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteCheckedException {
+    public <R> R saveOrGet(IgniteInternalFuture<R> fut) throws IgniteCheckedException {
         if (curFut != null) {
             curFut.set(fut);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
deleted file mode 100644
index 5c67f55..0000000
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
+++ /dev/null
@@ -1,189 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.lang;
-
-import org.apache.ignite.*;
-import org.jetbrains.annotations.*;
-
-import java.util.concurrent.*;
-
-/**
- * Extension for standard {@link Future} interface. It adds simplified exception handling,
- * functional programming support and ability to listen for future completion via functional
- * callback.
- * @param <R> Type of the result for the future.
- */
-public interface IgniteFuture<R> {
-    /**
-     * Synchronously waits for completion of the computation and
-     * returns computation result.
-     *
-     * @return Computation result.
-     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
-     */
-    public R get() throws IgniteCheckedException;
-
-    /**
-     * Synchronously waits for completion of the computation for
-     * up to the timeout specified and returns computation result.
-     * This method is equivalent to calling {@link #get(long, TimeUnit) get(long, TimeUnit.MILLISECONDS)}.
-     *
-     * @param timeout The maximum time to wait in milliseconds.
-     * @return Computation result.
-     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
-     */
-    public R get(long timeout) throws IgniteCheckedException;
-
-    /**
-     * Synchronously waits for completion of the computation for
-     * up to the timeout specified and returns computation result.
-     *
-     * @param timeout The maximum time to wait.
-     * @param unit The time unit of the {@code timeout} argument.
-     * @return Computation result.
-     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
-     */
-    public R get(long timeout, TimeUnit unit) throws IgniteCheckedException;
-
-    /**
-     * Cancels this future.
-     *
-     * @return {@code True} if future was canceled (i.e. was not finished prior to this call).
-     * @throws IgniteCheckedException If cancellation failed.
-     */
-    public boolean cancel() throws IgniteCheckedException;
-
-    /**
-     * Checks if computation is done.
-     *
-     * @return {@code True} if computation is done, {@code false} otherwise.
-     */
-    public boolean isDone();
-
-    /**
-     * Returns {@code true} if this computation was cancelled before it completed normally.
-     *
-     * @return {@code True} if this computation was cancelled before it completed normally.
-     */
-    public boolean isCancelled();
-
-    /**
-     * Gets start time for this future.
-     *
-     * @return Start time for this future.
-     */
-    public long startTime();
-
-    /**
-     * Gets duration in milliseconds between start of the future and current time if future
-     * is not finished, or between start and finish of this future.
-     *
-     * @return Time in milliseconds this future has taken to execute.
-     */
-    public long duration();
-
-    /**
-     * Flag to turn on or off synchronous listener notification. If this flag is {@code true}, then
-     * upon future completion the notification may happen in the same thread that created
-     * the future. This becomes especially important when adding listener to a future that
-     * is already {@code done} - if this flag is {@code true}, then listener will be
-     * immediately notified within the same thread.
-     * <p>
-     * Default value is {@code false}. To change the default, set
-     * {@link IgniteSystemProperties#GG_FUT_SYNC_NOTIFICATION} system property to {@code true}.
-     *
-     * @param syncNotify Flag to turn on or off synchronous listener notification.
-     */
-    public void syncNotify(boolean syncNotify);
-
-    /**
-     * Gets value of synchronous listener notification flag. If this flag is {@code true}, then
-     * upon future completion the notification may happen in the same thread that created
-     * the future. This becomes especially important when adding listener to a future that
-     * is already {@code done} - if this flag is {@code true}, then listener will be
-     * immediately notified within the same thread.
-     * <p>
-     * Default value is {@code false}. To change the default, set
-     * {@link IgniteSystemProperties#GG_FUT_SYNC_NOTIFICATION} system property to {@code true}.
-     *
-     * @return Synchronous listener notification flag.
-     */
-    public boolean syncNotify();
-
-    /**
-     * Flag to turn on or off concurrent listener notification. This flag comes into play only
-     * when a future has more than one listener subscribed to it. If this flag is {@code true},
-     * then all listeners will be notified concurrently by different threads; otherwise,
-     * listeners will be notified one after another within one thread (depending on
-     * {@link #syncNotify()} flag, these notifications may happen either in the same thread which
-     * started the future, or in a different thread).
-     * <p>
-     * Default value is {@code false}. To change the default, set
-     * {@link IgniteSystemProperties#GG_FUT_CONCURRENT_NOTIFICATION} system property to {@code true}.
-     *
-     * @param concurNotify Flag to turn on or off concurrent listener notification.
-     */
-    public void concurrentNotify(boolean concurNotify);
-
-    /**
-     * Gets value concurrent listener notification flag. This flag comes into play only
-     * when a future has more than one listener subscribed to it. If this flag is {@code true},
-     * then all listeners will be notified concurrently by different threads; otherwise,
-     * listeners will be notified one after another within one thread (depending on
-     * {@link #syncNotify()} flag, these notifications may happen either in the same thread which
-     * started the future, or in a different thread).
-     * <p>
-     * Default value is {@code false}. To change the default, set
-     * {@link IgniteSystemProperties#GG_FUT_CONCURRENT_NOTIFICATION} system property to {@code true}.
-     *
-     * @return Concurrent listener notification flag
-     */
-    public boolean concurrentNotify();
-
-    /**
-     * Registers listener closure to be asynchronously notified whenever future completes.
-     *
-     * @param lsnr Listener closure to register. If not provided - this method is no-op.
-     */
-    public void listenAsync(@Nullable IgniteInClosure<? super IgniteFuture<R>> lsnr);
-
-    /**
-     * Removes given listeners from the future. If no listener is passed in, then all listeners
-     * will be removed.
-     *
-     * @param lsnr Listeners to remove.
-     */
-    public void stopListenAsync(@Nullable IgniteInClosure<? super IgniteFuture<R>>... lsnr);
-
-    /**
-     * Make a chained future to convert result of this future (when complete) into a new format.
-     * It is guaranteed that done callback will be called only ONCE.
-     *
-     * @param doneCb Done callback that is applied to this future when it finishes to produce chained future result.
-     * @return Chained future that finishes after this future completes and done callback is called.
-     */
-    public <T> IgniteFuture<T> chain(IgniteClosure<? super IgniteFuture<R>, T> doneCb);
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
index 006bec2..c064197 100644
--- a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
@@ -18,7 +18,7 @@
 package org.apache.ignite.scheduler;
 
 import org.apache.ignite.*;
-import org.apache.ignite.lang.*;
+import org.apache.ignite.internal.*;
 
 import java.util.concurrent.*;
 
@@ -27,7 +27,7 @@ import java.util.concurrent.*;
  * when calling {@link org.apache.ignite.IgniteScheduler#scheduleLocal(Callable, String)} or
  * {@link org.apache.ignite.IgniteScheduler#scheduleLocal(Runnable, String)} methods.
  */
-public interface SchedulerFuture<R> extends IgniteFuture<R> {
+public interface SchedulerFuture<R> extends IgniteInternalFuture<R> {
     /**
      * Gets scheduled task ID.
      *

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
index 9568472..547a332 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
@@ -268,7 +268,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
     private final Object mux = new Object();
 
     /** Map with proceeding ping requests. */
-    private final ConcurrentMap<InetSocketAddress, IgniteFuture<IgniteBiTuple<UUID, Boolean>>> pingMap =
+    private final ConcurrentMap<InetSocketAddress, IgniteInternalFuture<IgniteBiTuple<UUID, Boolean>>> pingMap =
         new ConcurrentHashMap8<>();
 
     /** Debug mode. */
@@ -1169,7 +1169,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
         GridFutureAdapterEx<IgniteBiTuple<UUID, Boolean>> fut = new GridFutureAdapterEx<>();
 
-        IgniteFuture<IgniteBiTuple<UUID, Boolean>> oldFut = pingMap.putIfAbsent(addr, fut);
+        IgniteInternalFuture<IgniteBiTuple<UUID, Boolean>> oldFut = pingMap.putIfAbsent(addr, fut);
 
         if (oldFut != null)
             return oldFut.get();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/GridTestTaskSession.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/GridTestTaskSession.java b/modules/core/src/test/java/org/apache/ignite/GridTestTaskSession.java
index b1d495a..b1b0825 100644
--- a/modules/core/src/test/java/org/apache/ignite/GridTestTaskSession.java
+++ b/modules/core/src/test/java/org/apache/ignite/GridTestTaskSession.java
@@ -17,8 +17,8 @@
 
 package org.apache.ignite;
 
-import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.lang.*;
 import org.jetbrains.annotations.*;
 
@@ -213,7 +213,7 @@ public class GridTestTaskSession implements ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public IgniteFuture<?> mapFuture() {
+    @Override public IgniteInternalFuture<?> mapFuture() {
         assert false : "Not implemented";
 
         return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/cache/store/GridCacheBalancingStoreSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/cache/store/GridCacheBalancingStoreSelfTest.java b/modules/core/src/test/java/org/apache/ignite/cache/store/GridCacheBalancingStoreSelfTest.java
index 0547573..34d5aba 100644
--- a/modules/core/src/test/java/org/apache/ignite/cache/store/GridCacheBalancingStoreSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/cache/store/GridCacheBalancingStoreSelfTest.java
@@ -17,6 +17,7 @@
 
 package org.apache.ignite.cache.store;
 
+import org.apache.ignite.internal.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.typedef.*;
 import org.apache.ignite.testframework.*;
@@ -47,7 +48,7 @@ public class GridCacheBalancingStoreSelfTest extends GridCommonAbstractTest {
 
         final AtomicBoolean finish = new AtomicBoolean();
 
-        IgniteFuture<Long> fut = GridTestUtils.runMultiThreadedAsync(new IgniteCallable<Void>() {
+        IgniteInternalFuture<Long> fut = GridTestUtils.runMultiThreadedAsync(new IgniteCallable<Void>() {
             @Override public Void call() throws Exception {
                 try {
                     ThreadLocalRandom rnd = ThreadLocalRandom.current();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java b/modules/core/src/test/java/org/apache/ignite/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
index 38a87e4..09c4e4f 100644
--- a/modules/core/src/test/java/org/apache/ignite/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
@@ -23,7 +23,6 @@ import org.apache.ignite.cache.store.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.processors.cache.*;
-import org.apache.ignite.lang.*;
 import org.apache.ignite.transactions.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -113,7 +112,7 @@ public class GridCacheJdbcBlobStoreMultithreadedSelfTest extends GridCommonAbstr
      * @throws Exception If failed.
      */
     public void testMultithreadedPut() throws Exception {
-        IgniteFuture<?> fut1 = runMultiThreadedAsync(new Callable<Object>() {
+        IgniteInternalFuture<?> fut1 = runMultiThreadedAsync(new Callable<Object>() {
             private final Random rnd = new Random();
 
             @Override public Object call() throws Exception {
@@ -127,7 +126,7 @@ public class GridCacheJdbcBlobStoreMultithreadedSelfTest extends GridCommonAbstr
             }
         }, 4, "put");
 
-        IgniteFuture<?> fut2 = runMultiThreadedAsync(new Callable<Object>() {
+        IgniteInternalFuture<?> fut2 = runMultiThreadedAsync(new Callable<Object>() {
             private final Random rnd = new Random();
 
             @Override public Object call() throws Exception {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/internal/GridJobMasterLeaveAwareSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/GridJobMasterLeaveAwareSelfTest.java b/modules/core/src/test/java/org/apache/ignite/internal/GridJobMasterLeaveAwareSelfTest.java
index f79a68a..f184821 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/GridJobMasterLeaveAwareSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/GridJobMasterLeaveAwareSelfTest.java
@@ -253,8 +253,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).withAsync();
 
                 comp.apply(new TestClosure(), "arg");
@@ -268,8 +268,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).withAsync();
 
                 comp.apply(new TestClosure(), Arrays.asList("arg1", "arg2"));
@@ -283,8 +283,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testApply3() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).withAsync();
 
                 comp.apply(new TestClosure(),
@@ -308,8 +308,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testRun1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.run(new TestRunnable());
@@ -323,8 +323,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testRun2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.run(Arrays.asList(new TestRunnable(), new TestRunnable()));
@@ -338,8 +338,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.call(new TestCallable());
@@ -353,8 +353,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall2() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.call(Arrays.asList(new TestCallable(), new TestCallable()));
@@ -368,8 +368,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testCall3() throws Exception {
-        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.call(
@@ -393,8 +393,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast1() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.broadcast(new TestRunnable());
@@ -408,8 +408,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast2() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.broadcast(new TestCallable());
@@ -423,8 +423,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testBroadcast3() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 comp.broadcast(new TestClosure(), "arg");
@@ -438,8 +438,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testAffinityRun() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 CacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -457,8 +457,8 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testAffinityCall() throws Exception {
-        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
+        testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteInternalFuture<?>>() {
+            @Override public IgniteInternalFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).withAsync();
 
                 CacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -500,7 +500,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      * @param taskStarter Task started.
      * @throws Exception If failed.
      */
-    private void testMasterLeaveAwareCallback(int expJobs, IgniteClosure<ClusterGroup, IgniteFuture<?>> taskStarter)
+    private void testMasterLeaveAwareCallback(int expJobs, IgniteClosure<ClusterGroup, IgniteInternalFuture<?>> taskStarter)
         throws Exception {
         jobLatch = new CountDownLatch(expJobs);
         invokeLatch  = new CountDownLatch(expJobs);
@@ -510,7 +510,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
 
         int lastGridIdx = GRID_CNT - 1;
 
-        IgniteFuture<?> fut = taskStarter.apply(grid(lastGridIdx).forPredicate(excludeLastPredicate()));
+        IgniteInternalFuture<?> fut = taskStarter.apply(grid(lastGridIdx).forPredicate(excludeLastPredicate()));
 
         jobLatch.await();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/internal/GridMultipleJobsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/GridMultipleJobsSelfTest.java b/modules/core/src/test/java/org/apache/ignite/internal/GridMultipleJobsSelfTest.java
index d6ec8ad..8b174c5 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/GridMultipleJobsSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/GridMultipleJobsSelfTest.java
@@ -152,13 +152,13 @@ public class GridMultipleJobsSelfTest extends GridCommonAbstractTest {
 
                     comp.call(job);
 
-                    IgniteFuture<Boolean> fut = comp.future();
+                    IgniteInternalFuture<Boolean> fut = comp.future();
 
                     if (cnt % LOG_MOD == 0)
                         X.println("Submitted jobs: " + cnt);
 
-                    fut.listenAsync(new CIX1<IgniteFuture<Boolean>>() {
-                        @Override public void applyx(IgniteFuture<Boolean> f) throws IgniteCheckedException {
+                    fut.listenAsync(new CIX1<IgniteInternalFuture<Boolean>>() {
+                        @Override public void applyx(IgniteInternalFuture<Boolean> f) throws IgniteCheckedException {
                             try {
                                 assert f.get();
                             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/internal/GridProjectionAbstractTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/GridProjectionAbstractTest.java b/modules/core/src/test/java/org/apache/ignite/internal/GridProjectionAbstractTest.java
index 9da8a0b..8350f81 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/GridProjectionAbstractTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/GridProjectionAbstractTest.java
@@ -327,7 +327,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(runJob);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -349,7 +349,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.run(jobs);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -369,7 +369,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(calJob);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -391,7 +391,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.call(jobs);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -411,7 +411,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, (String) null);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -433,7 +433,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, args);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -453,7 +453,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.broadcast(new TestClosure(), "arg");
 
-        IgniteFuture<Collection<String>> fut = comp.future();
+        IgniteInternalFuture<Collection<String>> fut = comp.future();
 
         waitForExecution(fut);
 
@@ -480,7 +480,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.apply(clrJob, args, rdc);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -502,7 +502,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
 
         comp.call(jobs, rdc);
 
-        IgniteFuture fut = comp.future();
+        IgniteInternalFuture fut = comp.future();
 
         waitForExecution(fut);
 
@@ -602,7 +602,7 @@ public abstract class GridProjectionAbstractTest extends GridCommonAbstractTest
      * @throws InterruptedException Thrown if wait was interrupted.
      */
     @SuppressWarnings({"UnconditionalWait"})
-    private void waitForExecution(IgniteFuture fut) throws InterruptedException {
+    private void waitForExecution(IgniteInternalFuture fut) throws InterruptedException {
         long sleep = 250;
 
         long threshold = System.currentTimeMillis() + WAIT_TIMEOUT;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/test/java/org/apache/ignite/internal/GridReduceSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/GridReduceSelfTest.java b/modules/core/src/test/java/org/apache/ignite/internal/GridReduceSelfTest.java
index db2e960..1a5c7fc 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/GridReduceSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/GridReduceSelfTest.java
@@ -108,7 +108,7 @@ public class GridReduceSelfTest extends GridCommonAbstractTest {
                 }
             });
 
-            IgniteFuture<Long> fut = comp.future();
+            IgniteInternalFuture<Long> fut = comp.future();
 
             assertEquals((Long)1L, fut.get());
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java b/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
index ced12e0..c21bf5f 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
@@ -22,6 +22,7 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.events.*;
+import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.util.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.future.*;
@@ -499,15 +500,15 @@ public class GridFunc {
     };
 
     /** */
-    private static final IgnitePredicate<IgniteFuture<?>> FINISHED_FUTURE = new IgnitePredicate<IgniteFuture<?>>() {
-        @Override public boolean apply(IgniteFuture<?> f) {
+    private static final IgnitePredicate<IgniteInternalFuture<?>> FINISHED_FUTURE = new IgnitePredicate<IgniteInternalFuture<?>>() {
+        @Override public boolean apply(IgniteInternalFuture<?> f) {
             return f.isDone();
         }
     };
 
     /** */
-    private static final IgnitePredicate<IgniteFuture<?>> UNFINISHED_FUTURE = new IgnitePredicate<IgniteFuture<?>>() {
-        @Override public boolean apply(IgniteFuture<?> f) {
+    private static final IgnitePredicate<IgniteInternalFuture<?>> UNFINISHED_FUTURE = new IgnitePredicate<IgniteInternalFuture<?>>() {
+        @Override public boolean apply(IgniteInternalFuture<?> f) {
             return !f.isDone();
         }
     };
@@ -2741,13 +2742,13 @@ public class GridFunc {
     }
 
     /**
      * Converts given object with interface {@link org.apache.ignite.lang.IgniteFuture} into an object implementing {@link Future}.
      *
      * @param fut Future to convert.
      * @param <T> Type of computation result.
      * @return Instance implementing {@link Future}.
      */
-    public static <T> Future<T> as(final IgniteFuture<T> fut) {
+    public static <T> Future<T> as(final IgniteInternalFuture<T> fut) {
         A.notNull(fut, "fut");
 
         return new GridSerializableFuture<T>() {
@@ -2809,14 +2810,14 @@ public class GridFunc {
     }
 
     /**
      * Gets closure that converts {@link org.apache.ignite.lang.IgniteFuture} to {@link Future}.
      *
      * @param <T> Type of future.
      * @return Closure that converts {@link org.apache.ignite.lang.IgniteFuture} to {@link Future}.
      */
-    public static <T> IgniteClosure<IgniteFuture<T>, Future<T>> future() {
-        return new C1<IgniteFuture<T>, Future<T>>() {
-            @Override public Future<T> apply(IgniteFuture<T> fut) {
+    public static <T> IgniteClosure<IgniteInternalFuture<T>, Future<T>> future() {
+        return new C1<IgniteInternalFuture<T>, Future<T>>() {
+            @Override public Future<T> apply(IgniteInternalFuture<T> fut) {
                 return as(fut);
             }
         };
@@ -8440,7 +8441,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(@Nullable IgniteFuture<T>... futs) throws IgniteCheckedException {
+    public static <T> void awaitAll(@Nullable IgniteInternalFuture<T>... futs) throws IgniteCheckedException {
         if (!isEmpty(futs))
             awaitAll(asList(futs));
     }
@@ -8451,7 +8452,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(@Nullable Collection<IgniteFuture<T>> futs) throws IgniteCheckedException {
+    public static <T> void awaitAll(@Nullable Collection<IgniteInternalFuture<T>> futs) throws IgniteCheckedException {
         awaitAll(0, null, futs);
     }
 
@@ -8462,7 +8463,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(long timeout, @Nullable Collection<IgniteFuture<T>> futs) throws IgniteCheckedException {
+    public static <T> void awaitAll(long timeout, @Nullable Collection<IgniteInternalFuture<T>> futs) throws IgniteCheckedException {
         awaitAll(timeout, null, futs);
     }
 
@@ -8478,7 +8479,7 @@ public class GridFunc {
      * @throws IgniteCheckedException If any of the futures failed.
      */
     @Nullable public static <T, R> R awaitAll(long timeout, @Nullable IgniteReducer<T, R> rdc,
-        @Nullable Collection<IgniteFuture<T>> futs) throws IgniteCheckedException {
+        @Nullable Collection<IgniteInternalFuture<T>> futs) throws IgniteCheckedException {
         if (futs == null || futs.isEmpty())
             return null;
 
@@ -8491,7 +8492,7 @@ public class GridFunc {
         // Note that it is important to wait in the natural order of collection and
         // not via listen method, because caller may actually add to this collection
         // concurrently while this method is in progress.
-        for (IgniteFuture<T> fut : futs) {
+        for (IgniteInternalFuture<T> fut : futs) {
             T t;
 
             if (timeout > 0) {
@@ -8523,7 +8524,7 @@ public class GridFunc {
      * @param <T> Type of computation result.
      * @return Completed future.
      */
-    public static <T> IgniteFuture<T> awaitOne(IgniteFuture<T>... futs) {
+    public static <T> IgniteInternalFuture<T> awaitOne(IgniteInternalFuture<T>... futs) {
         return isEmpty(futs) ? new GridFinishedFutureEx<T>() : awaitOne(asList(futs));
     }
 
@@ -8534,22 +8535,22 @@ public class GridFunc {
      * @param <T> Type of computation result.
      * @return Completed future.
      */
-    public static <T> IgniteFuture<T> awaitOne(Iterable<IgniteFuture<T>> futs) {
+    public static <T> IgniteInternalFuture<T> awaitOne(Iterable<IgniteInternalFuture<T>> futs) {
         if (F.isEmpty(futs))
             return new GridFinishedFutureEx<>();
 
         final CountDownLatch latch = new CountDownLatch(1);
 
-        final AtomicReference<IgniteFuture<T>> t = new AtomicReference<>();
+        final AtomicReference<IgniteInternalFuture<T>> t = new AtomicReference<>();
 
-        IgniteInClosure<IgniteFuture<T>> c = null;
+        IgniteInClosure<IgniteInternalFuture<T>> c = null;
 
-        for (IgniteFuture<T> fut : futs) {
+        for (IgniteInternalFuture<T> fut : futs) {
             if (fut != null) {
                 if (!fut.isDone()) {
                     if (c == null) {
-                        c = new CI1<IgniteFuture<T>>() {
-                            @Override public void apply(IgniteFuture<T> fut) {
+                        c = new CI1<IgniteInternalFuture<T>>() {
+                            @Override public void apply(IgniteInternalFuture<T> fut) {
                                 if (t.compareAndSet(null, fut))
                                     latch.countDown();
                             }
@@ -8581,7 +8582,7 @@ public class GridFunc {
         if (interrupted)
             Thread.currentThread().interrupt();
 
-        IgniteFuture<T> f = t.get();
+        IgniteInternalFuture<T> f = t.get();
 
         assert f != null;
 
@@ -8593,7 +8594,7 @@ public class GridFunc {
      *
      * @return Predicate for filtering finished futures.
      */
-    public static IgnitePredicate<IgniteFuture<?>> finishedFutures() {
+    public static IgnitePredicate<IgniteInternalFuture<?>> finishedFutures() {
         return FINISHED_FUTURE;
     }
 
@@ -8602,7 +8603,7 @@ public class GridFunc {
      *
      * @return Predicate for filtering unfinished futures.
      */
-    public static IgnitePredicate<IgniteFuture<?>> unfinishedFutures() {
+    public static IgnitePredicate<IgniteInternalFuture<?>> unfinishedFutures() {
         return UNFINISHED_FUTURE;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/d5bef132/modules/core/src/main/java/org/apache/ignite/internal/util/nio/GridNioFuture.java
----------------------------------------------------------------------
@@ -2741,13 +2742,13 @@ public class GridFunc {
 
     /**
-     * Converts given object with interface {@link org.apache.ignite.lang.IgniteFuture} into an object implementing {@link Future}.
+     * Converts given object with interface {@link org.apache.ignite.internal.IgniteInternalFuture} into an object implementing {@link Future}.
      *
      * @param fut Future to convert.
@@ -2809,14 +2810,14 @@ public class GridFunc {
 
     /**
-     * Gets closure that converts {@link org.apache.ignite.lang.IgniteFuture} to {@link Future}.
+     * Gets closure that converts {@link org.apache.ignite.internal.IgniteInternalFuture} to {@link Future}.
      *
      * @param <T> Type of future.
@@ -2809,14 +2810,14 @@ public class GridFunc {
      *
      * @param <T> Type of future.
-     * @return Closure that converts {@link org.apache.ignite.lang.IgniteFuture} to {@link Future}.
+     * @return Closure that converts {@link org.apache.ignite.internal.IgniteInternalFuture} to {@link Future}.
      */